CyKSUID
=======

Cython implementation of KSUID_(K-Sortable Globally Unique IDs).

.. _KSUID: https://github.com/segmentio/ksuid

LICENSE
-------

New BSD. See `License File <https://github.com/timonwong/cyksuid/blob/master/LICENSE.txt>`__.

Install
-------

``cyksuid`` is on the Python Package Index (PyPI):

::

    pip install cyksuid


Dependencies
------------

``cyksuid`` supports Python 2.6+ and Python 3.3+ with a common codebase.
It is developed in Cython, but requires no dependecies other than CPython
and a C compiler.
